summaryrefslogtreecommitdiff
path: root/libmailutils/string/cstrunescape.c
diff options
context:
space:
mode:
Diffstat (limited to 'libmailutils/string/cstrunescape.c')
-rw-r--r--libmailutils/string/cstrunescape.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/libmailutils/string/cstrunescape.c b/libmailutils/string/cstrunescape.c
index 51758ec75..9766dca19 100644
--- a/libmailutils/string/cstrunescape.c
+++ b/libmailutils/string/cstrunescape.c
@@ -1,5 +1,5 @@
/* GNU Mailutils -- a suite of utilities for electronic mail
- Copyright (C) 2016-2019 Free Software Foundation, Inc.
+ Copyright (C) 2016-2024 Free Software Foundation, Inc.
GNU Mailutils is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
/* Copy characters from IN to OUT. Replace each occurrences of backslash
followed by a character XTAB[i] with CHR[i].
- OUT should be large enough to accomodate the translated string (same length
+ OUT should be large enough to accommodate the translated string (same length
as IN, in the worst case). It is OK if IN==OUT.
Both XTAB and CHR must not be NULL and must contain the same number of
@@ -61,7 +61,7 @@ c_str_unescape (char const *in, char *out, char const *chr, char const *xtab)
out[j] = 0;
}
/* Modifies STR, by replacing each occurrence of \ followed by a charater
XTAB[i] with CHR[i].
Either XTAB or CHR can be NULL, in which case XTAB=CHR is assumed.
@@ -93,7 +93,7 @@ mu_c_str_unescape_inplace (char *str, char const *chr, char const *xtab)
}
/* A counterpart of mu_c_str_escape. Creates an allocated (using malloc(3))
- copy of STR, where each occurrence of \ followed by a charater XTAB[i]
+ copy of STR, where each occurrence of \ followed by a character XTAB[i]
is replaced with single character CHR[i].
Either XTAB or CHR can be NULL, in which case XTAB=CHR is assumed.
@@ -61,7 +61,7 @@ c_str_unescape (char const *in, char *out, char const *chr, char const *xtab)
out[j] = 0;
}
-/* Modifies STR, by replacing each occurrence of \ followed by a charater
+/* Modifies STR, by replacing each occurrence of \ followed by a character
XTAB[i] with CHR[i].
Either XTAB or CHR can be NULL, in which case XTAB=CHR is assumed.

Return to:

Send suggestions and report system problems to the System administrator.